@@ -401,9 +401,9 @@ class Library:
     def t32_executecommand(self, cmd, buffer_size):
         payload = buffer_size.to_bytes(4, byteorder="little")
         if isinstance(cmd, str):
-            payload += cmd.encode()
+            payload += cmd.encode() + b"\0"
         elif isinstance(cmd, bytes) or isinstance(cmd, bytearray):
-            payload += cmd
+            payload += cmd + b"\0"
         else:
             raise TypeError(type(cmd))
 
@@ -540,7 +540,10 @@ class Library:
 
         try:
             return self.generic_api_call(
-                rapi_cmd=RAPI_CMD_DEVICE_SPECIFIC, opt_arg=RAPI_DSCMD_BREAKPOINT_OBJ_WRITE, payload=payload,
+                rapi_cmd=RAPI_CMD_DEVICE_SPECIFIC,
+                opt_arg=RAPI_DSCMD_BREAKPOINT_OBJ_WRITE,
+                payload=payload,
+                force_length=3 + len(payload),
             )
 
         except T32_ERR_FN1:
@@ -576,8 +579,8 @@ class Library:
         )
 
     def t32_executefunction(self, func):
-        func_bytes = func.encode()
 
+        func_bytes = func.encode() + b"\0"
         payload = struct.pack("<I{}s".format(len(func_bytes)), 4096, func_bytes)
 
         try:
